<?php

namespace Bixo\Company\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Company\Actions\CompanyAction;
use Bixo\Company\Http\Requests\CompanyActionRequest;
use Bixo\Company\Http\Resources\CompanyResource;
use Bixo\Company\Models\Company;

/**
 * Admin web controller class.
 */
class CompanyActionController extends BaseController
{

    /**
     * Action controller function for company.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CompanyActionRequest $request, Company $company, $action)
    {
        try {
            $request = $request->all();
            $company = CompanyAction::run($action, $company, $request);

            $data = new CompanyResource($company);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('company::company.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/company/' . $company->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/company/' . $company->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
