<?php
namespace Bixo\Company\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Company\Events\CompanyAction as CompanyActionEvent;
use Bixo\Company\Models\Company;

class CompanyAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $company;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CompanyActionEvent $company
     */
    public function __construct(CompanyActionEvent $company)
    {
        $this->action = $event->action;
        $this->company = $company;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Company Approved - ' . config('app.name'))
            ->view('company::company.email.action', ['data' => $this->company]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
